Struct io_uring::cqueue::AvailableQueue[][src]

pub struct AvailableQueue<'a> { /* fields omitted */ }

A snapshot of the completion queue.

Implementations

impl AvailableQueue<'_>[src]

pub fn sync(&mut self)[src]

Synchronize this snapshot with the real queue.

pub fn capacity(&self) -> usize[src]

Get the total number of entries in the completion queue ring buffer.

pub fn is_full(&self) -> bool[src]

Returns true if the completion queue is at maximum capacity. If is_feature_nodrop is not set, this will cause any new completion queue events to be dropped by the kernel.

pub fn fill(&mut self, entries: &mut [MaybeUninit<Entry>]) -> usize[src]