Struct io_uring::cqueue::CompletionQueue [−][src]
An io_uring instance's completion queue. This stores all the I/O operations that have completed.
Implementations
impl CompletionQueue[src]
pub fn overflow(&self) -> u32[src]
If queue is full and is_feature_nodrop is not set,
new events may be dropped. This records the number of dropped events.
pub fn eventfd_disabled(&self) -> bool[src]
Whether eventfd notifications are disabled when a request is completed and queued to the CQ
ring. This library currently does not provide a way to set it, so this will always be
false.
Requires the unstable feature.
pub fn capacity(&self) -> usize[src]
Get the total number of entries in the completion queue ring buffer.
pub fn len(&self) -> usize[src]
Get the number of unread completion queue events in the ring buffer.
pub fn is_empty(&self) -> bool[src]
Returns true if there are no completion queue events to be processed.
pub fn is_full(&self) -> bool[src]
Returns true if the completion queue is at maximum capacity. If
is_feature_nodrop is not set, this will cause any
new completion queue events to be dropped by the kernel.
pub fn available(&mut self) -> AvailableQueue<'_>ⓘNotable traits for AvailableQueue<'_>
impl Iterator for AvailableQueue<'_> type Item = Entry;[src]
Notable traits for AvailableQueue<'_>
impl Iterator for AvailableQueue<'_> type Item = Entry;Take a snapshot of the completion queue.