pub struct LinkTimeout { /* fields omitted */ }
This request must be linked with another request through
Flags::IO_LINK which is described below.
Unlike Timeout, LinkTimeout acts on the linked request, not the completion queue.
The opcode of the operation. This can be passed to
Probe::is_supported to check if this operation is
supported with the current kernel.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.