Struct io_uring::opcode::PollAdd[][src]

pub struct PollAdd { /* fields omitted */ }
Poll the specified fd.

Unlike poll or epoll without EPOLLONESHOT, this interface always works in one shot mode. That is, once the poll operation is completed, it will have to be resubmitted.

Implementations

The bits that may be set in flags are defined in <poll.h>, and documented in poll(2).

The opcode of the operation. This can be passed to Probe::is_supported to check if this operation is supported with the current kernel.