pub struct PollRemove { /* fields omitted */ }
Remove an existing poll request.
If found, the result method of the cqueue::Entry will return 0.
If not found, result will return -libc::ENOENT.
The opcode of the operation. This can be passed to
Probe::is_supported to check if this operation is
supported with the current kernel.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.