Struct io_uring::opcode::ProvideBuffers[][src]

pub struct ProvideBuffers { /* fields omitted */ }
Register nbufs buffers that each have the length len with ids starting from big in the group bgid that can be used for any request. See BUFFER_SELECT for more info.

Requires the unstable feature.

Implementations

The opcode of the operation. This can be passed to Probe::is_supported to check if this operation is supported with the current kernel.