Struct io_uring::opcode::ReadFixed [−][src]
pub struct ReadFixed { /* fields omitted */ }Expand description
Read from pre-mapped buffers that have been previously registered with
Submitter::register_buffers.
The return values match those documented in the preadv2(2) man pages.
Implementations
The buf_index is an index into an array of fixed buffers,
and is only valid if fixed buffers were registered.
The opcode of the operation. This can be passed to
Probe::is_supported to check if this operation is
supported with the current kernel.
specified for read operations, contains a bitwise OR of per-I/O flags,
as described in the preadv2(2) man page.