Struct io_uring::opcode::RecvMsg[][src]

pub struct RecvMsg { /* fields omitted */ }
Receive a message on a socket, equivalent to recvmsg(2).

See also the description of SendMsg.

Implementations

The opcode of the operation. This can be passed to Probe::is_supported to check if this operation is supported with the current kernel.