Struct io_uring::opcode::SendMsg [−][src]
pub struct SendMsg { /* fields omitted */ }Expand description
Send a message on a socket, equivalent to send(2).
fd must be set to the socket file descriptor, addr must contains a pointer to the msghdr structure, and flags holds the flags associated with the system call.
Implementations
The opcode of the operation. This can be passed to
Probe::is_supported to check if this operation is
supported with the current kernel.