Struct io_uring::opcode::SyncFileRange[][src]

pub struct SyncFileRange { /* fields omitted */ }
Sync a file segment with disk, equivalent to sync_file_range(2).

Implementations

The opcode of the operation. This can be passed to Probe::is_supported to check if this operation is supported with the current kernel.

the offset method holds the offset in bytes

the flags method holds the flags for the command