Struct io_uring::squeue::Entry [−][src]
#[repr(transparent)]pub struct Entry(_);Expand description
An entry in the submission queue, representing a request for an I/O operation.
These can be created via the opcodes in opcode.
Implementations
Set the user data. This is an application-supplied value that will be passed straight through into the completion queue entry.
Set the personality of this event. You can obtain a personality using
Submitter::register_personality.
Requires the unstable feature.