Struct io_uring::squeue::SubmissionQueue [−][src]
pub struct SubmissionQueue<'a> { /* fields omitted */ }Expand description
An io_uring instance’s submission queue. This is used to send I/O requests to the kernel.
Implementations
Synchronize this type with the real submission queue.
This will flush any entries added by push or
push_multiple and will update the queue’s length if the kernel has
consumed some entries in the meantime.
When is_setup_sqpoll is set, whether the kernel
threads has gone to sleep and requires a system call to wake it up.
The number of invalid submission queue entries that have been encountered in the ring buffer.
Returns true if the completion queue ring is overflown.
Get the total number of entries in the submission queue ring buffer.
Returns true if the submission queue ring buffer has reached capacity, and no more events
can be added before the kernel consumes some.
Attempts to push several entries into the queue. If the queue does not have space for all of the entries, an error is returned.
Safety
Developers must ensure that parameters of all the entries (such as buffer) are valid and will be valid for the entire duration of the operation, otherwise it may cause memory problems.