Struct io_uring::IoUring [−][src]
pub struct IoUring { /* fields omitted */ }Expand description
IoUring instance
Implementations
Create a new IoUring instance with default configuration parameters. See Builder to
customize it further.
The entries sets the size of queue,
and its value should be the power of two.
Get the submitter of this io_uring instance, which can be used to submit submission queue events to the kernel for execution and to register files or buffers with it.
Get the parameters that were used to construct this instance.
Initiate asynchronous I/O. See Submitter::submit for more details.
Initiate and/or complete asynchronous I/O. See Submitter::submit_and_wait for more
details.
Get the submitter, submission queue and completion queue of the io_uring instance. This can be used to operate on the different parts of the io_uring instance independently.
If you use this method to obtain sq and cq,
please note that you need to drop or sync the queue before and after submit,
otherwise the queue will not be updated.
Get the submission queue of the io_uring instance. This is used to send I/O requests to the kernel.
Get the submission queue of the io_uring instance from a shared reference.
Safety
No other SubmissionQueues may exist when calling this function.
pub fn completion(&mut self) -> CompletionQueue<'_>ⓘNotable traits for CompletionQueue<'_>impl Iterator for CompletionQueue<'_> type Item = Entry;
pub fn completion(&mut self) -> CompletionQueue<'_>ⓘNotable traits for CompletionQueue<'_>impl Iterator for CompletionQueue<'_> type Item = Entry;
impl Iterator for CompletionQueue<'_> type Item = Entry;Get completion queue of the io_uring instance. This is used to receive I/O completion events from the kernel.
Get the completion queue of the io_uring instance from a shared reference.
Safety
No other CompletionQueues may exist when calling this function.