Struct io_uring::Parameters [−][src]
pub struct Parameters(_);Expand description
The parameters that were used to construct an IoUring.
Implementations
Whether a kernel thread is performing queue polling. Enabled with Builder::setup_sqpoll.
Whether waiting for completion events is done with a busy loop instead of using IRQs.
Enabled with Builder::setup_iopoll.
If this flag is set, the SQ and CQ rings were mapped with a single mmap(2) call. This
means that only two syscalls were used instead of three.
If this flag is set, io_uring supports never dropping completion events. If a completion event occurs and the CQ ring is full, the kernel stores the event internally until such a time that the CQ ring has room for more entries.
If this flag is set, applications can be certain that any data for async offload has been consumed when the kernel has consumed the SQE.
If this flag is set, applications can specify offset == -1 with Readv,
Writev, ReadFixed,
WriteFixed, Read and Write,
which behaves exactly like setting offset == -1 in preadv2(2) and pwritev2(2): it’ll use
(and update) the current file position.
This obviously comes with the caveat that if the application has multiple reads or writes in flight, then the end result will not be as expected. This is similar to threads sharing a file descriptor and doing IO using the current file position.
If this flag is set, then io_uring guarantees that both sync and async execution of
a request assumes the credentials of the task that called Submitter::enter to queue the requests.
If this flag isn’t set, then requests are issued with the credentials of the task that originally registered the io_uring.
If only one task is using a ring, then this flag doesn’t matter as the credentials will always be the same.
Note that this is the default behavior, tasks can still register different personalities
through Submitter::register_personality.
Whether async pollable I/O is fast.
See the commit message that introduced it for more details.
Requires the unstable feature.
Whether poll events are stored using 32 bits instead of 16. This allows the user to use
EPOLLEXCLUSIVE.
The number of submission queue entries allocated.
The number of completion queue entries allocated.