Module types

Module types 

Common Linux types not provided by libc.

Structs

BufRingEntry
CancelBuilder
CancelBuilder constructs match criteria for request cancellation.
CloneBuffersFlags
Options for Submitter::register_buffers_clone and Submitter::register_buffers_clone_offset.
DestinationSlot
A destination slot for sending fixed resources (e.g. opcode::MsgRingSendFd).
Fd
A file descriptor that has not been registered with io_uring.
Fixed
A file descriptor that has been registered with io_uring using Submitter::register_files or Submitter::register_files_sparse. This can reduce overhead compared to using Fd in some cases.
FsyncFlags
Options for Fsync.
FutexWaitV
Wrapper around futex_waitv as used in futex_waitv system call.
Napi
NAPI busy-poll configuration for Submitter::register_napi and Submitter::unregister_napi.
OpenHow
Wrapper around open_how as used in the openat2(2) system call.
RecvMsgOut
Helper structure for parsing the result of a multishot opcode::RecvMsg.
SubmitArgs
Submit arguments
TimeoutFlags
Options for Timeout.
Timespec
epoll_event
Opaque types, you should use epoll_event instead.
io_uring_region_desc
io_uring_zcrx_area_reg
io_uring_zcrx_cqe
io_uring_zcrx_ifq_reg
io_uring_zcrx_rqe
statx
Opaque types, you should use statx instead.

Enums

NapiTracking
Strategy the kernel uses to track which NAPI instances to busy-poll, used by [Napi::tracking].

Constants

IORING_MEM_REGION_TYPE_USER
IORING_ZCRX_AREA_MASK
IORING_ZCRX_AREA_SHIFT
IOU_PBUF_RING_INC
IOU_PBUF_RING_MMAP

Type Aliases

RwFlagsDeprecated