Napi

Struct Napi 

pub struct Napi(/* private fields */);
NAPI busy-poll configuration for Submitter::register_napi and Submitter::unregister_napi.

On (un)register the kernel writes the previous settings back into the value, which can be read with busy_poll_timeout and prefer_busy_poll.

Available since Linux 6.9.

Implementations

Source

impl Napi

pub const fn new() -> Self

pub const fn set_busy_poll_timeout(self, micros: u32) -> Self

Set the busy-poll timeout, in microseconds.

pub const fn set_prefer_busy_poll(self, enabled: bool) -> Self

Set whether the kernel should prefer busy-polling over interrupts.

pub const fn set_tracking(self, strategy: NapiTracking) -> Self

Set the tracking strategy.

pub const fn busy_poll_timeout(&self) -> u32

The busy-poll timeout, in microseconds.

pub const fn prefer_busy_poll(&self) -> bool

Whether busy-polling is preferred over interrupts.