Struct io_uring::cqueue::Entry [−][src]
#[repr(transparent)]pub struct Entry(_);Expand description
An entry in the completion queue, representing a complete I/O operation.
Implementations
The operation-specific result code. For example, for a Read
operation this is equivalent to the return value of the read(2) system call.
The user data of the request, as set by
Entry::user_data on the submission queue event.
Metadata related to the operation.
This is currently used for:
- Storing the selected buffer ID, if one was selected. See
BUFFER_SELECTfor more info.