Struct io_uring::cqueue::Entry [−][src]
An entry in the completion queue, representing a complete I/O operation.
Implementations
impl Entry[src]
pub fn result(&self) -> i32[src]
The operation-specific result code. For example, for a Read
operation this is equivalent to the return value of the read(2) system call.
pub fn user_data(&self) -> u64[src]
The user data of the request, as set by
Entry::user_data on the submission queue event.
pub fn flags(&self) -> u32[src]
Metadata related to the operation.
This is currently used for:
- Storing the selected buffer ID, if one was selected. See
BUFFER_SELECTfor more info.