Struct io_uring::opcode::PollAdd [−][src]
Poll the specified fd.
Unlike poll or epoll without EPOLLONESHOT, this interface always works in one shot mode.
That is, once the poll operation is completed, it will have to be resubmitted.
Implementations
impl PollAdd[src]
pub fn new(fd: impl UseFixed, flags: u32) -> Self[src]
The bits that may be set in flags are defined in <poll.h>,
and documented in poll(2).
pub const CODE: u8[src]
The opcode of the operation. This can be passed to
Probe::is_supported to check if this operation is
supported with the current kernel.
pub fn build(self) -> Entry[src]