Struct io_uring::squeue::AvailableQueue [−][src]
A snapshot of the submission queue.
Implementations
impl AvailableQueue<'_>[src]
pub fn sync(&mut self)[src]
Synchronize this snapshot with the real queue.
pub fn capacity(&self) -> usize[src]
Get the total number of entries in the submission queue ring buffer.
pub fn len(&self) -> usize[src]
Get the number of submission queue events in the ring buffer.
pub fn is_empty(&self) -> bool[src]
Returns true if the submission queue ring buffer is empty.
pub fn is_full(&self) -> bool[src]
Returns true if the submission queue ring buffer has reached capacity, and no more events
can be added before the kernel consumes some.
pub unsafe fn push(&mut self, Entry: Entry) -> Result<(), Entry>[src]
Attempts to push an Entry into the queue.
If the queue is full, the element is returned back as an error.
Safety
Developers must ensure that parameters of the Entry (such as buffer) are valid and will
be valid for the entire duration of the operation, otherwise it may cause memory problems.
pub unsafe fn push_multiple(
&mut self,
entries: &[Entry]
) -> Result<(), Insufficient>[src]
&mut self,
entries: &[Entry]
) -> Result<(), Insufficient>