Struct io_uring::squeue::SubmissionQueue [−][src]
An io_uring instance's submission queue. This contains all the I/O operations the application sends to the kernel.
Implementations
impl SubmissionQueue[src]
pub fn need_wakeup(&self) -> bool[src]
When is_setup_sqpoll is set, whether the kernel
threads has gone to sleep and requires a system call to wake it up.
pub fn dropped(&self) -> u32[src]
The number of invalid submission queue entries that have been encountered in the ring buffer.
pub fn cq_overflow(&self) -> bool[src]
Returns true if the completion queue ring is overflown.
Requires the unstable feature.
pub fn capacity(&self) -> usize[src]
Get the total number of entries in the submission queue ring buffer.
pub fn len(&self) -> usize[src]
Get the number of submission queue events in the ring buffer.
pub fn is_empty(&self) -> bool[src]
Returns true if the submission queue ring buffer is empty.
pub fn is_full(&self) -> bool[src]
Returns true if the submission queue ring buffer has reached capacity, and no more events
can be added before the kernel consumes some.
pub fn available(&mut self) -> AvailableQueue<'_>[src]
Take a snapshot of the submission queue.